@@ -18,6 +18,15 @@ class binance():
         stepper = 10.0 ** digits
         return math.trunc(stepper * number) / stepper
 
+    def create_key_file(self): 
+        """Function to create your .key file"""
+        API_KEY = str(input("Enter your API key :"))
+        SECRET_KEY = str(input("Enter your SECRET_KEY :"))
+        file = open("binance.key","w")
+        file.write(API_KEY+'\n')
+        file.write(SECRET_KEY)
+        file.close()
+
     def get_server_time(self):
         '''Function to get server time'''
         response = requests.get('https://api.binance.com/api/v3/time',params={}).json()
@@ -191,7 +200,6 @@ class binance():
             'symbol':symbol,
             'side':side,
             'type':'STOP_LOSS',
-            'timeInForce':'GTC',
             'quantity':self.truncate(quantity,6),
             'price':self.truncate(stopPrice,8),
             'timestamp': timestamp,
@@ -212,7 +220,6 @@ class binance():
             'symbol':symbol,
             'side':side,
             'type':'TAKE_PROFIT',
-            'timeInForce':'GTC',
             'quantity':self.truncate(quantity,6),
             'price':self.truncate(profitPrice,8),
             'timestamp': timestamp,
@@ -274,7 +281,16 @@ class kraken():
     def truncate(self,number, digits) -> float:
             stepper = 10.0 ** digits
             return math.trunc(stepper * number) / stepper
-        
+
+    def create_key_file(self): 
+        """Function to create your .key file"""
+        API_KEY = str(input("Enter your API key :"))
+        SECRET_KEY = str(input("Enter your SECRET_KEY :"))
+        file = open("kraken.key","w")
+        file.write(API_KEY+'\n')
+        file.write(SECRET_KEY)
+        file.close()
+
     def get_server_time(self):
         '''Function to get server time'''
         response = requests.get('https://api.kraken.com/0/public/Time',params={}).json()
